Stan Math Library: stan/math/prim/mat/err/check_unit_vector.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

check_unit_vector.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_ERR_CHECK_UNIT_VECTOR_HPP
2 #define STAN_MATH_PRIM_MAT_ERR_CHECK_UNIT_VECTOR_HPP
3
4 #include <stan/math/prim/arr/err/check_nonzero_size.hpp>
5 #include <stan/math/prim/scal/err/domain_error.hpp>
6 #include <stan/math/prim/mat/err/constraint_tolerance.hpp>
7 #include <stan/math/prim/mat/fun/Eigen.hpp>
8 #include <sstream>
9 #include <string>
10
11 namespace stan {
12
13 namespace math {
35 template <typename T_prob>
36 bool check_unit_vector(const char* function,
37 const char* name,
38 const Eigen::Matrix<T_prob,
39 Eigen::Dynamic, 1>& theta) {
40 check_nonzero_size(function, name, theta);
41 T_prob ssq = theta.squaredNorm();
42 if (!(fabs(1.0 - ssq) <= CONSTRAINT_TOLERANCE)) {
43 std::stringstream msg;
44 msg << "is not a valid unit vector."
45 << " The sum of the squares of the elements should be 1, but is ";
46 std::string msg_str(msg.str());
47 domain_error(function, name, ssq, msg_str.c_str());
48 }
49 return true;
50 }
51
52 }
53 }
54 #endif
stan::math::fabs
fvar< T > fabs(const fvar< T > &x)
Definition: fabs.hpp:14
stan
Definition: log_sum_exp.hpp:8
constraint_tolerance.hpp
stan::math::CONSTRAINT_TOLERANCE
const double CONSTRAINT_TOLERANCE
The tolerance for checking arithmetic bounds In rank and in simplexes.
Definition: constraint_tolerance.hpp:11
stan::math::check_nonzero_size
bool check_nonzero_size(const char *function, const char *name, const T_y &y)
Return true if the specified matrix/vector is of non-zero size.
Definition: check_nonzero_size.hpp:30
stan::math::domain_error
void domain_error(const char *function, const char *name, const T &y, const char *msg1, const char *msg2)
Throw a domain error with a consistently formatted message.
Definition: domain_error.hpp:32
Eigen.hpp
domain_error.hpp
stan::math::check_unit_vector
bool check_unit_vector(const char *function, const char *name, const Eigen::Matrix< T_prob, Eigen::Dynamic, 1 > &theta)
Return true if the specified vector is unit vector.
Definition: check_unit_vector.hpp:36
check_nonzero_size.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.